@@ -297,10 +297,14 @@ class File:
         @return: Path name as string.
         """
         assert isinstance(pathName, str), "sanitise, pathName not a str"
-        assert ".." not in pathName, ".. exists in pathName"
         assert not pathName.endswith(os.sep), "pathName ends with %s" % os.sep
 
+        pathName = str(Path(os.path.normpath(pathName)))
+
         while pathName.startswith(os.sep):
             pathName = pathName[1:]
 
-        return str(Path(pathName))
+        assert not pathName.startswith(".."), f"{pathName} starts with '..' "
+        assert "/.." not in pathName, f"{pathName} contains '/..' "
+
+        return pathName
